#ifndef __IUF_ASTFRACT
#define __IUF_ASTFRACT
/** This class represent a asteroid with a random silohuette.
It is derived from the Ast Class. The generation of the random
silohuette is done in the member function Build, that is called 
by all the constructors. The random silohuette is stored in a 
vector<Point3f>. */

class AstFract : public Ast
{
public:
	/** The polygon representing the asteroid silohuette. */
	vector<Point3f> P;

	/** Default constructor.
It should also start the build function to create the random silohuette;
*/
	AstFract(){
		Build();
	}

/** Specialized constructor to set also angular velocity and size.
It should also start the build function to create the random silohuette;
	*/
	AstFract(const Point3f &_p, const float _angle, const Point3f &_v, float _av,float _size):
			Ast(_p,_angle,_v,_av,_size){
				Build();
			}
/** 
Draw the asteroid shape.
Simply draw the polygon stored in P
*/
virtual	int Draw();

/** 
Build the fractal silouhette of the asteroid.
Build an initial triangle and then split each 
side the given number of times. The result is 
stored in the vector P.
*/
void Build(int SplitNum=2);
	

/** Get a polygon represented as a list of n point3f and returns a polygon with 2n sides and 2n vertices.

The position of each new vertex is calculated as follows:
Given two points p1 p2 and the barycenter of poligon cm:
\begin{itemize}
\item Find the bisector b of the angle p1 cm p2,
\item find the new point np on b at a distance that is the average of dist(p1,cm) and dist(p2,cm)
\item perturb np of a small quantity depending on dist(p1,p2) 
\end{itemize}
*/
void Split(list<Point3f> &p);

};
#endif